@@ -311,12 +311,13 @@ int main(int argc, char **argv) {
       switch (*optarg) {
         case '-':
           ++optarg;
-          if (optarg[scan_ulong(optarg, &ul)]) usage(); nicelvl =ul;
-          nicelvl *=-1;
+          if (optarg[scan_ulong(optarg, &ul)]) usage();
+          nicelvl =-ul;
           break;
         case '+': ++optarg;
         default:
-          if (optarg[scan_ulong(optarg, &ul)]) usage(); nicelvl =ul;
+          if (optarg[scan_ulong(optarg, &ul)]) usage();
+          nicelvl =ul;
           break;
       }
       break;
@@ -327,7 +328,7 @@ int main(int argc, char **argv) {
     case '0': nostdin =1; break;
     case '1': nostdout =1; break;
     case '2': nostderr =1; break;
-    case 'V': strerr_warn1("$Id: e46a05449578fd7b8ee604f3ea6e81cd77d7d6f8 $", 0);
+    case 'V': strerr_warn1("$Id: 77dfc11f6cabbc3e49bcaad51af65e3325082516 $", 0);
     case '?': usage();
     }
   argv +=optind;
