@@ -10,10 +10,10 @@ unsigned int str_chr(register const char *s,int c)
   ch = c;
   t = s;
   for (;;) {
-    if (!*t) break; if (*t == ch) break; ++t;
-    if (!*t) break; if (*t == ch) break; ++t;
-    if (!*t) break; if (*t == ch) break; ++t;
-    if (!*t) break; if (*t == ch) break; ++t;
+    if (!*t) { break; } if (*t == ch) break; ++t;
+    if (!*t) { break; } if (*t == ch) break; ++t;
+    if (!*t) { break; } if (*t == ch) break; ++t;
+    if (!*t) { break; } if (*t == ch) break; ++t;
   }
   return t - s;
 }
